@@ -1,20 +1,25 @@
 # Copyright 2011 Google Inc.
-# 
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 test.import <- function() {
-  # Verify that we get a graceful error rather than a segfault.
-  checkException(readProtoFiles("/etc/hosts"))
+    ## Verify that we get a graceful error rather than a segfault.
+    checkException(readProtoFiles(system.file("DESCRIPTION", package="RProtoBuf")))
+}
+
+test.assign.in.global <- function() {
+    xx.undef <<- 3
+    checkEquals(xx.undef, 3)
 }
